==> mono-4.2.2.10.tar.bz2: mono-4.2.2/external/referencesource/System.ServiceModel.Web/GlobalSuppressions.cs <==
//------------------------------------------------------------
// Copyright (c) Microsoft Corporation.  All rights reserved.
//------------------------------------------------------------

using System.Diagnostics.CodeAnalysis;

[module: SuppressMessage("Microsoft.Naming", "CA1703:ResourceStringsShouldBeSpelledCorrectly", Scope = "resource", Target = "System.ServiceModel.SR2.resources", MessageId = "Infos", Justification = "This represents the ParameterInfo class defined in System.Reflection")]
[module: SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", Scope = "namespace", Target = "System.Xml.Linq", MessageId = "Linq")]

// [....], BEGIN FxCop violations for code in Microsoft.Web.Script.Services.*
[module: SuppressMessage("Microsoft.Performance", "CA1810:InitializeReferenceTypeStaticFieldsInline", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceTypeData..cctor()")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceTypeData.ThrowCannotGenerateProxyForTypeError(System.Xml.XmlQualifiedName):System.Void")]
[module: SuppressMessage("Microsoft.Usage", "CA1801:ReviewUnusedParameters", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceClientProxyGenerator..ctor(System.String,System.Boolean)", MessageId = "debug")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceData.get_EnumTypeDictionary():System.Collections.Generic.Dictionary`2<System.Type,Microsoft.Web.Script.Services.WebServiceTypeData>")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceData.get_EnumTypes():System.Collections.Generic.IEnumerable`1<System.Type>")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceData.get_ServiceName():System.String")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceData.get_ServiceNamespace():System.String")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceMethodData.get_CacheDuration():System.Int32")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceMethodData.get_GetVerbEnabled():System.Boolean")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceMethodData.get_RequiresSession():System.Boolean")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceMethodData.set_CacheDuration(System.Int32):System.Void")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceMethodData.set_Owner(Microsoft.Web.Script.Services.WebServiceData):System.Void")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceMethodData.set_RequiresSession(System.Boolean):System.Void")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceParameterData.get_Index():System.Int32")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceParameterData.get_ParameterType():Microsoft.Web.Script.Services.WebServiceTypeData")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceTypeData.set_TypeName(System.String):System.Void")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceTypeData.set_TypeNamespace(System.String):System.Void")]
// [....], END FxCop violations for code in Microsoft.Web.Script.Services.*


[module: SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters", Scope = "member", Target = "System.Runtime.Serialization.DataContractContentExtensions.ReadAsDataContract(System.ServiceModel.Web.Client.Http.HttpContent,System.Runtime.Serialization.DataContractSerializer):T")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "System.Runtime.Serialization.Json.JsonContentExtensions.get_DefaultQuotas():System.Xml.XmlDictionaryReaderQuotas")]
[module: SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters", Scope = "member", Target = "System.Runtime.Serialization.Json.JsonContentExtensions.ReadAsJsonDataContract(System.ServiceModel.Web.Client.Http.HttpContent,System.Runtime.Serialization.Json.DataContractJsonSerializer):System.Object")]
[module: SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters", Scope = "member", Target = "System.Runtime.Serialization.Json.JsonContentExtensions.ReadAsJsonDataContract(System.ServiceModel.Web.Client.Http.HttpContent,System.Runtime.Serialization.Json.DataContractJsonSerializer):T")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetEditLink(System.ServiceModel.Syndication.SyndicationItem,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetEditMediaLink(System.ServiceModel.Syndication.SyndicationItem,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Microsoft.Usage", "CA1801:ReviewUnusedParameters", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetFirstPageLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink", MessageId = "throwIfNotPresent")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetFirstPageLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Microsoft.Usage", "CA1801:ReviewUnusedParameters", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetLastPageLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink", MessageId = "throwIfNotPresent")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetLastPageLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Microsoft.Globalization", "CA1303:DoNotPassLiteralsAsLocalizedParameters", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetMediaResourceUri(System.ServiceModel.Syndication.SyndicationItem):System.Uri", MessageId = "System.ArgumentException.#ctor(System.String)")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetMediaResourceUri(System.ServiceModel.Syndication.SyndicationItem):System.Uri")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetNextPageLink(System.ServiceModel.Syndication.SyndicationFeed):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Microsoft.Usage", "CA1801:ReviewUnusedParameters", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetPreviousPageLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink", MessageId = "throwIfNotPresent")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetPreviousPageLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetSelfLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetSelfLink(System.ServiceModel.Syndication.SyndicationItem,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.IsMediaEntry(System.ServiceModel.Syndication.SyndicationItem):System.Boolean")]

==> mono-4.4.2.11.tar.bz2: mono-4.4.2/external/referencesource/System.ServiceModel.Web/GlobalSuppressions.cs <==
//------------------------------------------------------------
// Copyright (c) Microsoft Corporation.  All rights reserved.
//------------------------------------------------------------

using System.Diagnostics.CodeAnalysis;

[module: SuppressMessage("Microsoft.Naming", "CA1703:ResourceStringsShouldBeSpelledCorrectly", Scope = "resource", Target = "System.ServiceModel.SR2.resources", MessageId = "Infos", Justification = "This represents the ParameterInfo class defined in System.Reflection")]
[module: SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", Scope = "namespace", Target = "System.Xml.Linq", MessageId = "Linq")]

// krisragh, BEGIN FxCop violations for code in Microsoft.Web.Script.Services.*
[module: SuppressMessage("Microsoft.Performance", "CA1810:InitializeReferenceTypeStaticFieldsInline", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceTypeData..cctor()")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceTypeData.ThrowCannotGenerateProxyForTypeError(System.Xml.XmlQualifiedName):System.Void")]
[module: SuppressMessage("Microsoft.Usage", "CA1801:ReviewUnusedParameters", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceClientProxyGenerator..ctor(System.String,System.Boolean)", MessageId = "debug")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceData.get_EnumTypeDictionary():System.Collections.Generic.Dictionary`2<System.Type,Microsoft.Web.Script.Services.WebServiceTypeData>")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceData.get_EnumTypes():System.Collections.Generic.IEnumerable`1<System.Type>")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceData.get_ServiceName():System.String")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceData.get_ServiceNamespace():System.String")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceMethodData.get_CacheDuration():System.Int32")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceMethodData.get_GetVerbEnabled():System.Boolean")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceMethodData.get_RequiresSession():System.Boolean")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceMethodData.set_CacheDuration(System.Int32):System.Void")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceMethodData.set_Owner(Microsoft.Web.Script.Services.WebServiceData):System.Void")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceMethodData.set_RequiresSession(System.Boolean):System.Void")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceParameterData.get_Index():System.Int32")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceParameterData.get_ParameterType():Microsoft.Web.Script.Services.WebServiceTypeData")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceTypeData.set_TypeName(System.String):System.Void")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "Microsoft.Web.Script.Services.WebServiceTypeData.set_TypeNamespace(System.String):System.Void")]
// krisragh, END FxCop violations for code in Microsoft.Web.Script.Services.*


[module: SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters", Scope = "member", Target = "System.Runtime.Serialization.DataContractContentExtensions.ReadAsDataContract(System.ServiceModel.Web.Client.Http.HttpContent,System.Runtime.Serialization.DataContractSerializer):T")]
[module: SuppressMessage("Microsoft.Performance", "CA1811:AvoidUncalledPrivateCode", Scope = "member", Target = "System.Runtime.Serialization.Json.JsonContentExtensions.get_DefaultQuotas():System.Xml.XmlDictionaryReaderQuotas")]
[module: SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters", Scope = "member", Target = "System.Runtime.Serialization.Json.JsonContentExtensions.ReadAsJsonDataContract(System.ServiceModel.Web.Client.Http.HttpContent,System.Runtime.Serialization.Json.DataContractJsonSerializer):System.Object")]
[module: SuppressMessage("Microsoft.Design", "CA1011:ConsiderPassingBaseTypesAsParameters", Scope = "member", Target = "System.Runtime.Serialization.Json.JsonContentExtensions.ReadAsJsonDataContract(System.ServiceModel.Web.Client.Http.HttpContent,System.Runtime.Serialization.Json.DataContractJsonSerializer):T")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetEditLink(System.ServiceModel.Syndication.SyndicationItem,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetEditMediaLink(System.ServiceModel.Syndication.SyndicationItem,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Microsoft.Usage", "CA1801:ReviewUnusedParameters", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetFirstPageLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink", MessageId = "throwIfNotPresent")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetFirstPageLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Microsoft.Usage", "CA1801:ReviewUnusedParameters", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetLastPageLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink", MessageId = "throwIfNotPresent")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetLastPageLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Microsoft.Globalization", "CA1303:DoNotPassLiteralsAsLocalizedParameters", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetMediaResourceUri(System.ServiceModel.Syndication.SyndicationItem):System.Uri", MessageId = "System.ArgumentException.#ctor(System.String)")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetMediaResourceUri(System.ServiceModel.Syndication.SyndicationItem):System.Uri")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetNextPageLink(System.ServiceModel.Syndication.SyndicationFeed):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Microsoft.Usage", "CA1801:ReviewUnusedParameters", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetPreviousPageLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink", MessageId = "throwIfNotPresent")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetPreviousPageLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetSelfLink(System.ServiceModel.Syndication.SyndicationFeed,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.GetSelfLink(System.ServiceModel.Syndication.SyndicationItem,System.Boolean):System.ServiceModel.Syndication.SyndicationLink")]
[module: SuppressMessage("Reliability", "Reliability102:WrapExceptionsRule", Scope = "member", Target = "System.ServiceModel.Syndication.SyndicationFeedExtensions.IsMediaEntry(System.ServiceModel.Syndication.SyndicationItem):System.Boolean")]
